@@ -1,8 +1,6 @@
-import uno
+﻿import uno
 import unohelper
-
-from lightproof_opts_pt_BR import lopts
-from lightproof_opts_pt_BR import lopts_default
+import lightproof_opts_pt_BR
 from lightproof_impl_pt_BR import pkg
 
 from com.sun.star.lang import XServiceInfo
@@ -14,7 +12,7 @@ options = {}
 def load(context):
     try:
         l = LightproofOptionsEventHandler(context)
-        for i in lopts:
+        for i in lightproof_opts_pt_BR.lopts:
             l.load(i)
     except:
         pass
@@ -24,9 +22,9 @@ def get_option(page, option):
         return options[page + "," + option]
     except:
         try:
-                return options[page[:2] + "," + option]
+            return options[page[:2] + "," + option]
         except:
-                return 0
+            return 0
 
 def set_option(page, option, value):
     options[page + "," + option] = int(value)
@@ -45,7 +43,7 @@ class LightproofOptionsEventHandler( unohelper.Base, XServiceInfo, XContainerWin
     # XContainerWindowEventHandler
     def callHandlerMethod(self, aWindow, aEventObject, sMethod):
         if sMethod == "external_event":
-                return self.handleExternalEvent(aWindow, aEventObject)
+            return self.handleExternalEvent(aWindow, aEventObject)
 
     def getSupportedMethodNames(self):
         return ("external_event", )
@@ -53,65 +51,65 @@ class LightproofOptionsEventHandler( unohelper.Base, XServiceInfo, XContainerWin
     def handleExternalEvent(self, aWindow, aEventObject):
         sMethod = aEventObject
         if sMethod == "ok":
-                self.saveData(aWindow)
+            self.saveData(aWindow)
         elif sMethod == "back" or sMethod == "initialize":
-                self.loadData(aWindow)
+            self.loadData(aWindow)
         return True
 
     def load(self, sWindowName):
         child = self.getChild(sWindowName)
-        for i in lopts[sWindowName]:
-                sValue = child.getPropertyValue(i)
-                if sValue == '':
-                    if i in lopts_default[sWindowName]:
-                        sValue = 1
-                    else:
-                        sValue = 0
-                set_option(sWindowName, i, sValue)
+        for i in lightproof_opts_pt_BR.lopts[sWindowName]:
+            sValue = child.getPropertyValue(i)
+            if sValue == '':
+                if i in lightproof_opts_pt_BR.lopts_default[sWindowName]:
+                    sValue = 1
+                else:
+                    sValue = 0
+            set_option(sWindowName, i, sValue)
 
     def loadData(self, aWindow):
         sWindowName = self.getWindowName(aWindow)
         if (sWindowName == None):
-                return
+            return
         child = self.getChild(sWindowName)
-        for i in lopts[sWindowName]:
-                sValue = child.getPropertyValue(i)
-                if sValue == '':
-                    if i in lopts_default[sWindowName]:
-                        sValue = 1
-                    else:
-                        sValue = 0
-                xControl = aWindow.getControl(i)
-                xControl.State = sValue
-                set_option(sWindowName, i, sValue)
+        for i in lightproof_opts_pt_BR.lopts[sWindowName]:
+            sValue = child.getPropertyValue(i)
+            if sValue == '':
+                if i in lightproof_opts_pt_BR.lopts_default[sWindowName]:
+                    sValue = 1
+                else:
+                    sValue = 0
+            xControl = aWindow.getControl(i)
+            xControl.State = sValue
+            set_option(sWindowName, i, sValue)
 
     def saveData(self, aWindow):
         sWindowName = self.getWindowName(aWindow)
         if (sWindowName == None):
-                return
+            return
         child = self.getChild(sWindowName)
-        for i in lopts[sWindowName]:
-                xControl = aWindow.getControl(i)
-                sValue = xControl.State
-                child.setPropertyValue(i, str(sValue))
-                set_option(sWindowName, i, sValue)
+        for i in lightproof_opts_pt_BR.lopts[sWindowName]:
+            xControl = aWindow.getControl(i)
+            sValue = xControl.State
+            child.setPropertyValue(i, str(sValue))
+            set_option(sWindowName, i, sValue)
         self.commitChanges()
 
     def getWindowName(self, aWindow):
         sName = aWindow.getModel().Name
-        if sName in lopts:
-                return sName
+        if sName in lightproof_opts_pt_BR.lopts:
+            return sName
         return None
 
     # XServiceInfo method implementations
     def getImplementationName (self):
-                return self.ImplementationName
+        return self.ImplementationName
 
     def supportsService(self, ServiceName):
-                return (ServiceName in self.services)
+        return (ServiceName in self.services)
 
     def getSupportedServiceNames (self):
-                return self.services
+        return self.services
 
     def getChild(self, name):
         return self.node.getByName(name)
